==> spip_4.1.7+dfsg.orig.tar.xz: ecrire/lang/public_ar.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=ar
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'الصفحة الرئيسية',
	'article' => 'مقال',
	'articles' => 'المقالات',
	'articles_auteur' => 'مقالات هذا المؤلف',
	'articles_populaires' => 'المقالات الأكثر شعبية',
	'articles_rubrique' => 'مقالات هذا القسم',
	'aucun_article' => 'لا توجد مقالات على هذا العنوان',
	'aucun_auteur' => 'لا يوجد مؤلفون على هذا العنوان',
	'aucun_site' => 'لا توجد مواقع على هذا العنوان',
	'aucune_breve' => 'لا توجد أخبار على هذا العنوان',
	'aucune_rubrique' => 'لا توجد أقسام على هذا العنوان',
	'auteur' => 'مؤلف',
	'autres' => 'آخرون',
	'autres_breves' => 'أخبار أخرى',
	'autres_groupes_mots_clefs' => 'مجموعات مفاتيح أخرى',
	'autres_sites' => 'مواقع أخرى',

	// B
	'bonjour' => 'أهلاً وسهلاً',

	// C
	'commenter_site' => 'تعليق على هذا الموقع',
	'contact' => 'للاتصال',
	'copie_document_impossible' => 'لا يمكن نسخ المستند',

	// D
	'date' => 'التاريخ',
	'dernier_ajout' => 'آخر إضافة',
	'dernieres_breves' => 'آخر الأخبار',
	'derniers_articles' => 'آخر المقالات',
	'derniers_commentaires' => 'آخر التعليقات',
	'derniers_messages_forum' => 'آخر المشاركات المنشورة في المنتديات',

	// E
	'edition_mode_texte' => 'النشرة في وضعية النصوص',
	'en_reponse' => 'رداً على:',
	'en_resume' => 'باختصار',
	'envoyer_message' => 'إرسال مشاركة',
	'espace_prive' => 'المجال الخاص',

	// F
	'formats_acceptes' => 'التنسيقات المسموحة: @formats@.',

	// H
	'hierarchie_site' => 'هرمية الموقع',

	// J
	'jours' => 'يوم',

	// L
	'lien_connecter' => 'دخول',

	// M
	'meme_auteur' => 'من نفس المؤلف',
	'meme_rubrique' => 'في هذا القسم أيضاً',
	'memes_auteurs' => 'من المؤلفين نفسهم ايضاً',
	'message' => 'مشاركة',
	'messages_forum' => 'مشاركة منتدى',
	'messages_recents' => 'أحدث المشاركات',
	'mots_clef' => 'مفتاح',
	'mots_clefs' => 'المفاتيح',
	'mots_clefs_meme_groupe' => 'المفاتيح الأخرى في هذه المجموعة',

	// N
	'navigation' => 'تصفح',
	'nom' => 'الاسم',
	'nouveautes' => 'الجديد',
	'nouveautes_web' => 'الجديد على النسيج',
	'nouveaux_articles' => 'المقالات الجديدة',
	'nouvelles_breves' => 'الأخبار الجديدة',

	// P
	'page_precedente' => 'الصفحة السابقة',
	'page_suivante' => 'الصفحة التالية',
	'par_auteur' => 'بقلم ',
	'participer_site' => 'يمكنك المشاركة في هذا الموقع، بالتسجيل أدناه ونشر مقالاتك. وبعد التسجيل، سوف تصلك رسالة فورية بالبريد الإلكتروني تتضمن معرفك الخاص الذي يسمح لك بالدخول الى المجال الخاص.',
	'plan_site' => 'خريطة الموقع',
	'popularite' => 'الشعبية',
	'poster_message' => 'إبعث برسالة',
	'proposer_site' => 'يمكنك افتراح إضافة موقع الى هذا القسم:',

	// R
	'repondre_article' => 'الرد على هذا المقال',
	'repondre_breve' => 'الرد على هذا الخبر',
	'resultats_recherche' => 'نتائج البحث',
	'retour_debut_forums' => 'عودة الى بداية المنتديات',
	'rss_abonnement' => 'نسخ عن،ان URL التالي في مجمّع RSS:',
	'rss_abonnement_titre' => 'الاشتراك',
	'rss_abonnement_titre_page' => 'الاشتراك في',
	'rss_explication' => 'يجمع خيط RSS معلومات حول تحديث موقع. ويوفر محتوى تذاكر التحديث او التعليقات او مقتطفات منها إضافة الى رابط الى المحتويات الكاملة وبعض المعلومات الإضافية. هذا الخيط يُقرأ بواسطة مجمّع RSS.',
	'rss_explication_titre' => 'ما هو تدفق RSS؟',
	'rubrique' => 'القسم',
	'rubriques' => 'الأقسام',

	// S
	'signatures_petition' => 'التوقيعات',
	'site_realise_avec_spip' => 'موقع صمم بنظام SPIP',
	'sites_web' => 'مواقع النسيج',
	'sous_rubriques' => 'الأقسام الفرعية',
	'spam' => 'خنزرة',
	'suite' => 'تتمة',
	'sur_web' => 'على النسيج',
	'syndiquer_rubrique' => 'ترخيص هذا القسم',
	'syndiquer_site' => 'ترخيص كامل الموقع',

	// T
	'texte_lettre_information' => 'ها هي نشرة الموقع',
	'texte_lettre_information_2' => 'تحصي هذه النشرة المقالات والأخبار المنشورة منذ ',

	// V
	'ver_imprimer' => 'نسخة للطباعة',
	'voir_en_ligne' => 'عرض مباشر',
	'voir_squelette' => 'عرض الصفحة النموذجية لهذه الصفحة'
);

==> spip_4.4.3+dfsg.orig.tar.xz: ecrire/lang/public_ar.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=ar
// ** ne pas modifier le fichier **

return [

	// A
	'accueil_site' => 'الصفحة الرئيسية',
	'article' => 'مقال',
	'articles' => 'المقالات',
	'articles_auteur' => 'مقالات هذا المؤلف',
	'articles_populaires' => 'المقالات الأكثر شعبية',
	'articles_rubrique' => 'مقالات هذا القسم',
	'aucun_article' => 'لا توجد مقالات على هذا العنوان',
	'aucun_auteur' => 'لا يوجد مؤلفون على هذا العنوان',
	'aucun_site' => 'لا توجد مواقع على هذا العنوان',
	'aucune_breve' => 'لا توجد أخبار على هذا العنوان',
	'aucune_rubrique' => 'لا توجد أقسام على هذا العنوان',
	'auteur' => 'مؤلف',
	'autres' => 'آخرون',
	'autres_breves' => 'أخبار أخرى',
	'autres_groupes_mots_clefs' => 'مجموعات مفاتيح أخرى',
	'autres_sites' => 'مواقع أخرى',

	// B
	'bonjour' => 'أهلاً وسهلاً',

	// C
	'commenter_site' => 'تعليق على هذا الموقع',
	'contact' => 'للاتصال',
	'copie_document_impossible' => 'لا يمكن نسخ المستند',

	// D
	'date' => 'التاريخ',
	'dernier_ajout' => 'آخر إضافة',
	'dernieres_breves' => 'آخر الأخبار',
	'derniers_articles' => 'آخر المقالات',
	'derniers_commentaires' => 'آخر التعليقات',
	'derniers_messages_forum' => 'آخر المشاركات المنشورة في المنتديات',

	// E
	'edition_mode_texte' => 'النشرة في وضعية النصوص',
	'en_reponse' => 'رداً على:',
	'en_resume' => 'باختصار',
	'envoyer_message' => 'إرسال مشاركة',
	'espace_prive' => 'المجال الخاص',

	// F
	'formats_acceptes' => 'التنسيقات المسموحة: @formats@.',

	// H
	'hierarchie_site' => 'هرمية الموقع',

	// J
	'jours' => 'يوم',

	// L
	'lien_connecter' => 'دخول',

	// M
	'meme_auteur' => 'من نفس المؤلف',
	'meme_rubrique' => 'في هذا القسم أيضاً',
	'memes_auteurs' => 'من المؤلفين نفسهم ايضاً',
	'message' => 'مشاركة',
	'messages_forum' => 'مشاركة منتدى',
	'messages_recents' => 'أحدث المشاركات',
	'mots_clef' => 'مفتاح',
	'mots_clefs' => 'المفاتيح',
	'mots_clefs_meme_groupe' => 'المفاتيح الأخرى في هذه المجموعة',

	// N
	'navigation' => 'تصفح',
	'nom' => 'الاسم',
	'nouveautes' => 'الجديد',
	'nouveautes_web' => 'الجديد على النسيج',
	'nouveaux_articles' => 'المقالات الجديدة',
	'nouvelles_breves' => 'الأخبار الجديدة',

	// P
	'page_precedente' => 'الصفحة السابقة',
	'page_suivante' => 'الصفحة التالية',
	'par_auteur' => 'بقلم ',
	'participer_site' => 'يمكنك المشاركة في هذا الموقع، بالتسجيل أدناه ونشر مقالاتك. وبعد التسجيل، سوف تصلك رسالة فورية بالبريد الإلكتروني تتضمن معرفك الخاص الذي يسمح لك بالدخول الى المجال الخاص.',
	'plan_site' => 'خريطة الموقع',
	'popularite' => 'الشعبية',
	'poster_message' => 'إبعث برسالة',
	'proposer_site' => 'يمكنك افتراح إضافة موقع الى هذا القسم:',

	// R
	'repondre_article' => 'الرد على هذا المقال',
	'repondre_breve' => 'الرد على هذا الخبر',
	'resultats_recherche' => 'نتائج البحث',
	'retour_debut_forums' => 'عودة الى بداية المنتديات',
	'rss_abonnement' => 'نسخ عن،ان URL التالي في مجمّع RSS:',
	'rss_abonnement_titre' => 'الاشتراك',
	'rss_abonnement_titre_page' => 'الاشتراك في',
	'rss_explication' => 'يجمع خيط RSS معلومات حول تحديث موقع. ويوفر محتوى تذاكر التحديث او التعليقات او مقتطفات منها إضافة الى رابط الى المحتويات الكاملة وبعض المعلومات الإضافية. هذا الخيط يُقرأ بواسطة مجمّع RSS.',
	'rss_explication_titre' => 'ما هو تدفق RSS؟',
	'rubrique' => 'القسم',
	'rubriques' => 'الأقسام',

	// S
	'signatures_petition' => 'التوقيعات',
	'site_realise_avec_spip' => 'موقع صمم بنظام SPIP',
	'sites_web' => 'مواقع النسيج',
	'sous_rubriques' => 'الأقسام الفرعية',
	'spam' => 'خنزرة',
	'suite' => 'تتمة',
	'sur_web' => 'على النسيج',
	'syndiquer_rubrique' => 'ترخيص هذا القسم',
	'syndiquer_site' => 'ترخيص كامل الموقع',

	// T
	'texte_lettre_information' => 'ها هي نشرة الموقع',
	'texte_lettre_information_2' => 'تحصي هذه النشرة المقالات والأخبار المنشورة منذ ',

	// V
	'ver_imprimer' => 'نسخة للطباعة',
	'voir_en_ligne' => 'عرض مباشر',
	'voir_squelette' => 'عرض الصفحة النموذجية لهذه الصفحة',
];
